@@ -59,6 +59,10 @@ class FileSystem(ABC):
     def rm(self, paths: str):
         pass
 
+    @abstractmethod
+    def write_csv(self, df: pd.DataFrame, filename: str):
+        pass
+
     def grep(self, iterable: iter, regex: str) -> list:
         return [obj for obj in iterable if re.match(rf'{regex}', obj)]
 
@@ -242,6 +246,14 @@ class MinioFS(FileSystem):
         for filename in filenames:
             self.__client__.remove_object(bucket_name=bucket, object_name=filename)
 
+    def write_csv(self, df, filename):
+        bucket, filepath = self._process_path(filename)
+        csv_bytes = df.to_csv(index=None, header=None).encode('utf-8')
+        csv_buffer = BytesIO(csv_bytes)
+        self.__client__.put_object(bucket, filepath, data=csv_buffer,
+                                    length=len(csv_bytes), content_type='application/csv')
+
+
 
 class LocalFS(FileSystem):
     def lb(self, grep=None):
@@ -349,3 +361,6 @@ class LocalFS(FileSystem):
             os.remove(path)
         return
 
+    def write_csv(self, df, filename):
+        df.to_csv(filename, index=None, header=None)
+
